=======
History
=======

0.1.2 (2012-04-07)
------------------
* Added scale invariant probability functional to all models
* Improved methods for convergence with change in API, xtol now a relative measure
* Added pagerank and trophic depth to the library
* Added methods for graph conversion to networkx
* Added methods for computing the adjacency matrix as a sparse matrix

0.1.1 (2021-03-29)
------------------
* Fixed bug in stripe expected degree computation
* Added testing of expected degree performance

0.1.0 (2021-03-29)
------------------
* Added the block model and group info to graphs
* Added fast implementation of theoretical expected degrees
* Fixed some compatibility issues with multiple item assignments

0.0.4 (2021-03-15)
------------------
* Fixed issues with slow pandas index conversion

0.0.3 (2021-03-14)
------------------
* Large changes in API with great improvements in usability
* Added sampling function
* Added RandomGraph model
* Added Graph classes for ease of use


0.0.2 (2020-11-13)
------------------
* Added steps for CI. 
* Corrected broken links. 
* Removed support for python 3.5 and 3.6

0.0.1 (2020-10-28)
------------------

* First release on PyPI. StripeFitnessModel available, all other model classes still dummies.

